Documentation
¶
Overview ¶
Package tool defines built-in coding-agent tools as a publishable library.
Layout:
catalog/ — tool names, categories, and the built-in catalog exposure/ — name resolution and runtime executability schema/ — provider API JSON schemas and exposure filter websearch/ — reusable multi-engine web search todolist/ — TodoList tool state and argument handling
Tool execution and approval UI live in internal/ (coding-agent).
Index ¶
- Constants
- func FilterProviderTools(tools []protocol.ToolDefinition) []protocol.ToolDefinition
- func IsExecutable(name string) bool
- func IsProviderExposed(name string) bool
- func Names() []string
- func ProviderDefinitions() []protocol.ToolDefinition
- func RequiresApproval(name string) bool
- func ResolveName(raw string) (canonical string, known bool)
- type Approval
- type Category
- type Definition
Constants ¶
const ( CategoryFile = catalog.CategoryFile CategoryShell = catalog.CategoryShell CategoryWeb = catalog.CategoryWeb CategoryPlanMode = catalog.CategoryPlanMode CategoryStateManagement = catalog.CategoryStateManagement CategoryCollaboration = catalog.CategoryCollaboration CategoryGoal = catalog.CategoryGoal ApprovalAutoAllow = catalog.ApprovalAutoAllow ApprovalRequiresApproval = catalog.ApprovalRequiresApproval ApprovalAlwaysApprove = catalog.ApprovalAlwaysApprove Read = catalog.Read Write = catalog.Write Edit = catalog.Edit Grep = catalog.Grep Glob = catalog.Glob ReadMediaFile = catalog.ReadMediaFile Bash = catalog.Bash FetchURL = catalog.FetchURL WebSearch = catalog.WebSearch CodeSearch = catalog.CodeSearch EnterPlanMode = catalog.EnterPlanMode ExitPlanMode = catalog.ExitPlanMode AskUser = catalog.AskUser Skill = catalog.Skill TodoList = catalog.TodoList CreateGoal = catalog.CreateGoal GetGoal = catalog.GetGoal UpdateGoal = catalog.UpdateGoal SetGoalBudget = catalog.SetGoalBudget )
Variables ¶
This section is empty.
Functions ¶
func FilterProviderTools ¶
func FilterProviderTools(tools []protocol.ToolDefinition) []protocol.ToolDefinition
func IsExecutable ¶
func IsProviderExposed ¶
func ProviderDefinitions ¶
func ProviderDefinitions() []protocol.ToolDefinition
func RequiresApproval ¶
func ResolveName ¶
Types ¶
type Definition ¶
type Definition = catalog.Definition
func All ¶
func All() []Definition
func ByCategory ¶
func ByCategory(category Category) []Definition
func Get ¶
func Get(name string) (Definition, bool)
Directories
¶
| Path | Synopsis |
|---|---|
|
Package codesearch searches code on GitHub and GitLab.
|
Package codesearch searches code on GitHub and GitLab. |
|
Package fetchurl fetches remote HTTP(S) content for the FetchURL agent tool.
|
Package fetchurl fetches remote HTTP(S) content for the FetchURL agent tool. |
|
Package goal implements Goal tool state, types, and a context-scoped store for CreateGoal, GetGoal, UpdateGoal, and SetGoalBudget tool execution.
|
Package goal implements Goal tool state, types, and a context-scoped store for CreateGoal, GetGoal, UpdateGoal, and SetGoalBudget tool execution. |
|
Package todolist implements TodoList tool state and argument handling.
|
Package todolist implements TodoList tool state and argument handling. |
|
Package websearch implements reusable multi-engine web search with ENV-based provider selection and DuckDuckGo fallback.
|
Package websearch implements reusable multi-engine web search with ENV-based provider selection and DuckDuckGo fallback. |
Click to show internal directories.
Click to hide internal directories.